==> lxqt-config_0.13.0.orig.tar.xz: lxqt-config-0.13.0/lxqt-config-appearance/styleconfig.h <==
/* BEGIN_COMMON_COPYRIGHT_HEADER
 * (c)LGPL2+
 *
 * LXQt - a lightweight, Qt based, desktop toolset
 * https://lxqt.org
 *
 * Copyright: 2012 Razor team
 * Authors:
 *   Alexander Sokoloff <sokoloff.a@gmail.com>
 *
 * This program or library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * END_COMMON_COPYRIGHT_HEADER */

#ifndef STYLECONFIG_H
#define STYLECONFIG_H

#include <QWidget>
#include <LXQt/Settings>

class QTreeWidgetItem;
class QSettings;

namespace Ui {
    class StyleConfig;
}

class StyleConfig : public QWidget
{
    Q_OBJECT

public:
    explicit StyleConfig(LXQt::Settings *settings, QSettings *qtSettings, QWidget *parent = 0);
    ~StyleConfig();

public slots:
    void initControls();

private slots:
    void styleSelected(QTreeWidgetItem* item, int column);
    void toolButtonStyleSelected(int index);
    void singleClickActivateToggled(bool toggled);

private:
    Ui::StyleConfig *ui;
    QSettings *mQtSettings;
    LXQt::Settings *mSettings;
};

#endif // STYLECONFIG_H

==> lxqt-config_0.14.1.1+rb2.orig.tar.xz: lxqt-config-0.14.1.1+rb2/lxqt-config-appearance/styleconfig.h <==
/* BEGIN_COMMON_COPYRIGHT_HEADER
 * (c)LGPL2+
 *
 * LXQt - a lightweight, Qt based, desktop toolset
 * https://lxqt.org
 *
 * Copyright: 2012 Razor team
 * Authors:
 *   Alexander Sokoloff <sokoloff.a@gmail.com>
 *
 * This program or library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * END_COMMON_COPYRIGHT_HEADER */

#ifndef STYLECONFIG_H
#define STYLECONFIG_H

#include <QWidget>
#include <LXQt/Settings>
#include "configothertoolkits.h"

class QTreeWidgetItem;
class QSettings;

namespace Ui {
    class StyleConfig;
}

class StyleConfig : public QWidget
{
    Q_OBJECT

public:
    explicit StyleConfig(LXQt::Settings *settings,
        QSettings *qtSettings, LXQt::Settings *configAppearanceSettings,
        ConfigOtherToolKits *configOtherToolKits, QWidget *parent = 0);
    ~StyleConfig();

    void applyStyle();

public slots:
    void initControls();

signals:
    void settingsChanged();

private slots:
    void showAdvancedOptions(bool on);

private:
    Ui::StyleConfig *ui;
    QSettings *mQtSettings;
    LXQt::Settings *mSettings;
    LXQt::Settings *mConfigAppearanceSettings;
    ConfigOtherToolKits *mConfigOtherToolKits;
};

#endif // STYLECONFIG_H
